@@ -69,7 +69,7 @@ public class ColumnConfigGenerator {
 				public void render(
 						com.google.gwt.cell.client.Cell.Context context,
 						Date value, SafeHtmlBuilder sb) {
-					// yyyy/MM/dd HH:mm:ss 
+					
 					DateTimeFormat sdf= DateTimeFormat.getFormat("yyyy-MM-dd");
 					String v = String.valueOf(sdf.format(value));
 					sb.appendHtmlConstant(v);
@@ -92,7 +92,11 @@ public class ColumnConfigGenerator {
 			columnConfig = ColumnConfigGenerator
 					.<Long> create(columnDefinition);
 			break;
-		case STRING: {
+		case GEOMETRY:
+			columnConfig = ColumnConfigGenerator
+			.<String> create(columnDefinition);
+			break;
+		case STRING: 
 
 			columnConfig = ColumnConfigGenerator
 					.<String> create(columnDefinition);
@@ -104,7 +108,7 @@ public class ColumnConfigGenerator {
 			 * SafeHtmlUtils.fromString(object); } }) );
 			 */
 
-		}
+		
 			break;
 		default:
 			return null;
@@ -198,6 +202,11 @@ public class ColumnConfigGenerator {
 						new NumberField<Long>(
 								new NumberPropertyEditor.LongPropertyEditor()));
 				break;
+			case GEOMETRY:
+				editableGrid.addEditor(
+						(ColumnConfig<DataRow, String>) columnConfig,
+						new TextField());
+				break;	
 			case STRING:
 				editableGrid.addEditor(
 						(ColumnConfig<DataRow, String>) columnConfig,
